/*
 * (C) Copyright IBM Corporation 2016.
*/
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA

 Author: IBM Corporation and/or HCL Technologies Ltd.
 This module is part of the IBM (R) Rational (R) ClearCase (R)(*)
 Multi-version file system (MVFS).
 For support, please visit http://www.ibm.com/software/support

 * ClearCase is a trademark of IBM Corporation, registered in many
   jurisdictions, and is used under license.
*/
#ifndef MVFS_VIEWROOT_DEFS_H_
#define MVFS_VIEWROOT_DEFS_H_

/* There are two kinds of viewroots: dynamic and automatic (called remote views
** or rviews in a server context).  We need to identify them in some parameter
** lists (e.g., tbs_view_root_type()), so we define an enum for that purpose.
** Note, the enum values should be sequential from MNVWROOT to MXVWROOT so that
** they can be iterated over in a loop to handle all viewroot types.
*/
typedef enum mvfs_viewroot_type {
    NOVWROOT = -1,              /* Uninitialized viewroot type. */
    MNVWROOT = 0,               /* Minimum viewroot type value. */
    DYVWROOT = 0,               /* Dynamic view. */
    AUVWROOT = 1,               /* Automatic view (aka rview). */
    MXVWROOT = 1                /* Maximum viewroot type value. */
} mvfs_viewroot_type_t;

/* Define a constant for array allocations based on mvfs_viewroot_type_t. */
#define MVFS_VIEWROOT_SZ ((MXVWROOT - MNVWROOT) + 1)

/* Define a macro to provide a string representation of the viewroot type. */
#define MVFS_VWROOT_TO_STR(vrt) \
    ((vrt) == DYVWROOT ? "dynamic" : \
     ((vrt) == AUVWROOT ? "automatic" : "unknown"))

/*
 * Name of file on viewroot to open for all ioctl's.  Each viewroot has its own
 * specdev (with this name) and there are different "well known" symlinks to get
 * to them.
 */
#define MVFS_SPECDEV ".specdev"

/*
 * Name of canned pathname relative to the
 * 'hostdata' dir for the specdev device.
 * This is actually a symlink created by mount_mfs
 * to the <viewroot_mount_point>/.specdev
 * Normal usage is:
 *	tbs_product_hostdata_dir(pname, MVFS_SPECDEV_HOSTDATA_RELPN)
 */
#define MVFS_SPECDEV_HOSTDATA_RELPN     "clearcase_specdev"
#define MVFS_RSPECDEV_HOSTDATA_RELPN    "clearcase_rspecdev"

#endif /* MVFS_VIEWROOT_DEFS_H_ */
/* $Id: d9ad5b10.7d2e11e7.878d.00:01:86:0c:f4:86 $ */
